@@ -231,8 +231,8 @@ def main():
 
     parser = argparse.ArgumentParser(description='millConnect order creator.')
     parser.add_argument('projectPath', nargs='?', type=Path, default=None, help='The path to a project folder.')
-    parser.add_argument('--host', nargs='?', type=str, default='http://mhcicddev01.millhouse.local:8000/v1', help='The URL of the api, default: http://mhcicddev01.millhouse.local:8000/v1')
-    parser.add_argument('--uploadURL', nargs='?', type=str, default='http://mhcicddev01.millhouse.local/uploadOrder', help='The URL to open in the browser, default: http://mhcicddev01.millhouse.local/uploadOrder')
+    parser.add_argument('--host', nargs='?', type=str, default='https://api.connect.millhouse.local/v1', help='The URL of the api, default: https://api.connect.millhouse.local/v1')
+    parser.add_argument('--uploadURL', nargs='?', type=str, default='https://connect.millhouse.local/uploadOrder', help='The URL to open in the browser, default: https://connect.millhouse.local/uploadOrder')
     parser.add_argument('--no-update', action='store_true', help='Do not check for updates.')
     args = parser.parse_args()
 
